@@ -527,15 +527,13 @@ import org.cprover.CProverString;
 
     /**
      * @diffblue.fullSupport
-     * @diffblue.untested
      */
     @Override
     public synchronized StringBuffer append(int i) {
-        // DIFFBLUE MODEL LIBRARY this is replaced internally
         // toStringCache = null;
         // super.append(i);
         // return this;
-        return CProver.nondetWithoutNullForNotModelled();
+        return append(String.valueOf(i));
     }
 
     /**
@@ -568,28 +566,24 @@ import org.cprover.CProverString;
 
     /**
      * @diffblue.fullSupport
-     * @diffblue.untested
      */
     @Override
     public synchronized StringBuffer append(float f) {
-        // DIFFBLUE MODEL LIBRARY this is replaced internally
         // toStringCache = null;
         // super.append(f);
         // return this;
-        return CProver.nondetWithoutNullForNotModelled();
+        return append(String.valueOf(f));
     }
 
     /**
-     * @diffblue.fullSupport
-     * @diffblue.untested
+     * @diffblue.partialSupport This uses float approximation, so might return incorrect results
      */
     @Override
     public synchronized StringBuffer append(double d) {
-        // DIFFBLUE MODEL LIBRARY this is replaced internally
         // toStringCache = null;
         // super.append(d);
         // return this;
-        return CProver.nondetWithoutNullForNotModelled();
+        return append(String.valueOf(d));
     }
 
     /**
